@@ -669,6 +669,18 @@ class AppArmorPolicyModificationTests(unittest.TestCase):
         profile = 'invalid_policy_does_not_exist_dont_use'
         click.unload_profile(profile)
 
+    def test_apparmor_not_available(self):
+        '''Test apparmor not available'''
+        try:
+            click.apparmor_available(parser="/nonexistent",
+                                     apparmor_dirs=['/nonexistent.dir'])
+        except click.AppArmorException:
+            return
+        except Exception:
+            raise
+        raise Exception("apparmor_available should have failed")
+
+
 if __name__ == '__main__':
     suite = unittest.TestSuite()
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(T))
